\item\begin{tabular*}{1.0\textwidth}[t]{@{}l@{\extracolsep{\fill}}r@{}}
\textbf{ {{ left_top|escape_tex -}} } & {{ right_top|escape_tex }} \\
\textit{\small {{ left_bottom|escape_tex -}} } & \textit{\small {{ right_bottom|escape_tex }}} \\
\end{tabular*}
