\usepackage{latexsym}
\usepackage[letterpaper, margin=0.4in]{geometry}
\usepackage[hidelinks]{hyperref}
\input{glyphtounicode}

\setlength{\parindent}{0pt}
\setlength{\parskip}{0pt}

\newcommand{\resumesection}[1]{
  \par\vspace{5pt}
  {\normalfont\large\scshape\raggedright\noindent #1}
  \par\vspace{3pt}
  \hrule\par\vspace{5pt}
}

\newenvironment{resumeitemize}{
  \begin{list}{}{
    \setlength{\leftmargin}{0pt}
    \setlength{\itemindent}{0pt}
    \setlength{\labelwidth}{0pt}
    \setlength{\labelsep}{0pt}
    \setlength{\listparindent}{0pt}
    \setlength{\itemsep}{0pt}
    \setlength{\parsep}{0pt}
    \setlength{\topsep}{0pt}
    \setlength{\partopsep}{0pt}
  }
}{\end{list}}

\newenvironment{resumebullets}{
  \begin{itemize}
    \setlength{\leftmargin}{1.5em}
    \setlength{\labelsep}{5pt}
    \setlength{\itemsep}{1pt}
    \setlength{\parsep}{0pt}
    \setlength{\topsep}{0pt}
    \setlength{\partopsep}{0pt}
}{\end{itemize}}

\urlstyle{same}
\raggedbottom
\raggedright
\setlength{\tabcolsep}{0in}

% Ensure ATS readability
\pdfgentounicode=1
